@@ -5,17 +5,17 @@
 from w3bsite.classes.config import *
 from w3bsite.classes.utils import utils
 from w3bsite.classes import defaults as _defaults_
-if not Environment.get("MIGRATIONS", format=bool, default=False):
+if not dev0s.env.get("MIGRATIONS", format=bool, default=False):
 	try:
 		from django.contrib.auth.models import User as DjangoUser
 		from django.contrib.auth import authenticate, login
 		from django.contrib.auth import login as _login_
 	except Exception as e:
-		if Environment.get_boolean("DJANGO_RUNNING") == True:
+		if dev0s.env.get_boolean("DJANGO_RUNNING") == True:
 			raise ValueError(e)
 
 # the django object class.
-class Django(_defaults_.Defaults):
+class Django(_defaults_.dev0s.defaults.):
 	def __init__(self, 
 		# the security object.
 		security=None,
@@ -31,7 +31,7 @@ class Django(_defaults_.Defaults):
 			notes=[], )
 
 		# defaults.
-		_defaults_.Defaults.__init__(self, traceback="w3bsite.Website.django",)
+		_defaults_.dev0s.defaults.__init__(self, traceback="w3bsite.Website.django",)
 		self.assign(defaults.dict())
 
 		# arguments.
@@ -45,13 +45,13 @@ class Django(_defaults_.Defaults):
 	def start(self, host="127.0.0.1", port="8000", production=False):
 
 		# import main.
-		Environment.export(export="__defaults__/env/json", env={
+		dev0s.env.export(export="__defaults__/env/json", env={
 			"PRODUCTION": str(production),
 			"INTERACTIVE":False,
 		})
 		self.migrations()
-		if Defaults.options.log_level >= 1:
-			Response.log(f"Starting {self.name}.", save=True)
+		if dev0s.defaults.options.log_level >= 1:
+			dev0s.response.log(f"Starting {self.name}.", save=True)
 		os.chdir(self.root)
 		import manage
 		sys.argv = [f"{self.root}/manage.py", "runserver", f"{host}:{port}"]
@@ -96,7 +96,7 @@ class Django(_defaults_.Defaults):
 		'''
 
 		# handlers.
-		return Response.success(f"Successfully stopped website [{self.root}].")
+		return dev0s.response.success(f"Successfully stopped website [{self.root}].")
 
 		#
 	def create(self):
@@ -139,48 +139,48 @@ class Django(_defaults_.Defaults):
 		#os.system(f"chmod +x {path}")
 
 		# handlers.
-		return Response.success(f"Successfully created django website [{self.root}].")
+		return dev0s.response.success(f"Successfully created django website [{self.root}].")
 	def create_app(self, name="home"):
 
 		# checks.
 		path = f"{self.root}/apps/{name}"
 		if Files.exists(path):
-			return Response.error(f"App [{name}] already exists.")
+			return dev0s.response.error(f"App [{name}] already exists.")
 
 		# copy.
 		os.system(f"cp -r {SOURCE_PATH}/example/app {path}")
 
 		# handlers.
-		return Response.success(f"Successfully created app [{name}].")
-	def migrations(self, forced=False, log_level=Defaults.options.log_level):
+		return dev0s.response.success(f"Successfully created app [{name}].")
+	def migrations(self, forced=False, log_level=dev0s.defaults.options.log_level):
 		if not Files.exists(f"{self.database}/data/"): os.mkdir(f"{self.database}/data/")
 		if forced or not Files.exists(f"{self.database}/data/db.sqlite3"):
-			Response.log(f"Applying {ALIAS} webserver migrations.")
-			Environment.export(export="__defaults__/env/json", env={"MIGRATIONS": True,})
+			dev0s.response.log(f"Applying {ALIAS} webserver migrations.")
+			dev0s.env.export(export="__defaults__/env/json", env={"MIGRATIONS": True,})
 			os.chdir(self.root)
 			#import manage
 			#old_argv = list(sys.argv)
 			#sys.argv = [f"{self.root}/manage.py", "migrate"]
 			#manage.main()
 			os.system(f"cd {self.root} && python3 ./manage.py migrate")
-			Environment.export(export="__defaults__/env/json", env={"MIGRATIONS": False,})
+			dev0s.env.export(export="__defaults__/env/json", env={"MIGRATIONS": False,})
 			#sys.argv = old_argv
-		return Response.success(f"Successfully checked the migrations.")
-	def collect_static(self, log_level=Defaults.options.log_level):
+		return dev0s.response.success(f"Successfully checked the migrations.")
+	def collect_static(self, log_level=dev0s.defaults.options.log_level):
 		if log_level >= 1:
-			Response.log(f"Checking the {ALIAS} webserver migrations.")
+			dev0s.response.log(f"Checking the {ALIAS} webserver migrations.")
 		if not Files.exists(f"{self.database}/data/"): os.mkdir(f"{self.database}/data/")
-		Environment.export(export="__defaults__/env/json", env={
+		dev0s.env.export(export="__defaults__/env/json", env={
 			"MIGRATIONS": str(True),
 		})
 		os.system(f"cd {self.root}/ && . __defaults__/env/bash && export MIGRATIONS='true' && ./manage.py collectstatic" )
-		Environment.export(export="__defaults__/env/json", env={
+		dev0s.env.export(export="__defaults__/env/json", env={
 			"MIGRATIONS": str(False),
 		})
-		return Response.success(f"Successfully checked the static files.")
+		return dev0s.response.success(f"Successfully checked the static files.")
 
 # the django database users.
-class Users(_defaults_.Defaults):
+class Users(_defaults_.dev0s.defaults.):
 	def __init__(self, 
 		# defaults.
 		defaults=None,
@@ -193,7 +193,7 @@ class Users(_defaults_.Defaults):
 			notes=[], )
 
 		# defaults.
-		_defaults_.Defaults.__init__(self, traceback="w3bsite.Website.django.users")
+		_defaults_.dev0s.defaults.__init__(self, traceback="w3bsite.Website.django.users")
 		self.assign(defaults.dict())
 
 		#
@@ -205,7 +205,7 @@ class Users(_defaults_.Defaults):
 		superuser=False,
 	):
 		# check arguments.
-		response = Response.parameters.check(
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="create"),
 			parameters={
 				"username":username,
@@ -222,12 +222,12 @@ class Users(_defaults_.Defaults):
 			django_user.save()
 
 			# success.
-			return Response.success(f"Successfully created django user {username}.", {
+			return dev0s.response.success(f"Successfully created django user {username}.", {
 				"user":django_user,
 			})
 
 		# error.
-		except Exception as e:  return Response.error(f"Failed to create django user {username}, error: {e}.")
+		except Exception as e:  return dev0s.response.error(f"Failed to create django user {username}, error: {e}.")
 
 		#
 	def update(self,
@@ -240,7 +240,7 @@ class Users(_defaults_.Defaults):
 		superuser=None,
 	):
 		# check arguments.
-		response = Response.parameters.check(
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="update"),
 			parameters={
 				"username":username,
@@ -270,12 +270,12 @@ class Users(_defaults_.Defaults):
 			if edits > 0: django_user.save()
 
 			# success.
-			return Response.success(f"Successfully updated django user {username}.", {
+			return dev0s.response.success(f"Successfully updated django user {username}.", {
 				#"user":django_user,
 			})
 
 		# error.
-		except Exception as e:  return Response.error(f"Failed to update django user {username}, error: {e}.")
+		except Exception as e:  return dev0s.response.error(f"Failed to update django user {username}, error: {e}.")
 
 		#
 	def authenticate(self, 
@@ -289,7 +289,7 @@ class Users(_defaults_.Defaults):
 	):
 
 		# check arguments.
-		response = Response.parameters.check(
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="authenticate"),
 			parameters={
 				"username":username,
@@ -303,7 +303,7 @@ class Users(_defaults_.Defaults):
 			if user is not None: a=1
 			else:
 				response["error"] = f"Invalid verification."
-				Response.log(f"Invalid verification attempt for user [{username}].")
+				dev0s.response.log(f"Invalid verification attempt for user [{username}].")
 				return response
 
 			# success.
@@ -311,17 +311,17 @@ class Users(_defaults_.Defaults):
 				_login_(request, user)
 
 			# success.
-			return Response.success(f"Successfully authenticated user {username}.", {
+			return dev0s.response.success(f"Successfully authenticated user {username}.", {
 				#"user":django_user,
 			})
 		# error.
-		except Exception as e:  return Response.error(f"Failed to login user {username}, error: {e}.")
+		except Exception as e:  return dev0s.response.error(f"Failed to login user {username}, error: {e}.")
 
 		#
 	def delete(self, username=None):
 
 		# check arguments.
-		response = Response.parameters.check(
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="delete"),
 			parameters={
 				"username":username,
@@ -334,12 +334,12 @@ class Users(_defaults_.Defaults):
 			django_user.delete()
 
 			# success.
-			return Response.success(f"Successfully deleted django user {username}.", {
+			return dev0s.response.success(f"Successfully deleted django user {username}.", {
 				#"user":django_user,
 			})
 
 		# error.
-		except Exception as e:  return Response.error(f"Failed to delete django user {username}, error: {e}.")
+		except Exception as e:  return dev0s.response.error(f"Failed to delete django user {username}, error: {e}.")
 
 		#
 	def get(self, 
@@ -350,9 +350,9 @@ class Users(_defaults_.Defaults):
 
 		# checks.
 		if username != None and "@" in username:
-			raise Exceptions.InvalidUsage("An username can not contain a [@] character. You most likely passed an email for the username parameter.")
+			raise dev0s.exceptions.InvalidUsage("An username can not contain a [@] character. You most likely passed an email for the username parameter.")
 		if email != None and "@" not in email:
-			raise Exceptions.InvalidUsage(f"Invalid email [{email}].")
+			raise dev0s.exceptions.InvalidUsage(f"Invalid email [{email}].")
 
 		# by username.
 		identifier = None
@@ -364,7 +364,7 @@ class Users(_defaults_.Defaults):
 				django_user = DjangoUser.objects.get(username=username)
 
 			# error.
-			except Exception as e:  return Response.error(f"Failed to retrieve django user {identifier}, error: {e}.")
+			except Exception as e:  return dev0s.response.error(f"Failed to retrieve django user {identifier}, error: {e}.")
 
 		# by email.
 		elif email not in [None,"None"]:
@@ -375,13 +375,13 @@ class Users(_defaults_.Defaults):
 				django_user = DjangoUser.objects.get(email=email)
 
 			# error.
-			except Exception as e:  return Response.error(f"Failed to retrieve django user {identifier}, error: {e}.")
+			except Exception as e:  return dev0s.response.error(f"Failed to retrieve django user {identifier}, error: {e}.")
 
 		# invalid.
-		else: return Response.error(f"Define one of the following parameters: [username, email].")
+		else: return dev0s.response.error(f"Define one of the following parameters: [username, email].")
 
 		# success.
-		return Response.success(f"Successfully retrieved django user {identifier}.", {
+		return dev0s.response.success(f"Successfully retrieved django user {identifier}.", {
 			"user":django_user,
 			"username":django_user.username,
 			"email":django_user.email,
@@ -409,12 +409,12 @@ class Users(_defaults_.Defaults):
 				exists = DjangoUser.objects.filter(username=username).exists()
 
 				# success.
-				return Response.success(f"Successfully checked the existsance of django user {username}.", {
+				return dev0s.response.success(f"Successfully checked the existsance of django user {username}.", {
 					"exists":exists,
 				})
 
 			# error.
-			except Exception as e:  return Response.error(f"Failed to check the existsance of django user {username}, error: {e}.")
+			except Exception as e:  return dev0s.response.error(f"Failed to check the existsance of django user {username}, error: {e}.")
 
 		# by email.
 		elif email != None:
@@ -425,12 +425,12 @@ class Users(_defaults_.Defaults):
 			response = self.get(email=email)
 			if response.error != None and "User matching query does not exist" not in response.error: return response
 			elif response.error != None and "User matching query does not exist" in response.error: exists = False
-			return Response.success(f"Successfully checked the existsance of django user {identifier}.", {
+			return dev0s.response.success(f"Successfully checked the existsance of django user {identifier}.", {
 				"exists":exists,
 			})
 
 		# invalid.
-		else: return Response.error(f"Define one of the following parameters: [username, email].")
+		else: return dev0s.response.error(f"Define one of the following parameters: [username, email].")
 
 
 		#
