@@ -3,7 +3,7 @@
 
 # imports.
 from w3bsite.classes.config import *
-if not Environment.get("MIGRATIONS", format=bool, default=False):
+if not dev0s.env.get("MIGRATIONS", format=bool, default=False):
 	from django.contrib.auth.models import User as DjangoUser
 	from django.contrib.auth import authenticate, login
 	from django.contrib.auth import login as _login_
@@ -16,7 +16,7 @@ from w3bsite.classes import defaults as _defaults_
 from w3bsite.classes import email, utils
 
 # the users class.
-class Users(_defaults_.Defaults):
+class Users(_defaults_.dev0s.defaults.):
 	def __init__(self,
 		# noreply email settings.
 		email_enabled=True,
@@ -41,7 +41,7 @@ class Users(_defaults_.Defaults):
 			notes=[], )
 
 		# defaults.
-		_defaults_.Defaults.__init__(self, traceback="w3bsite.Website.users",)
+		_defaults_.dev0s.defaults.__init__(self, traceback="w3bsite.Website.users",)
 		self.assign(defaults.dict())
 
 		# variables.
@@ -116,7 +116,7 @@ class Users(_defaults_.Defaults):
 	):
 
 		# check parameters.
-		response = Response.parameters.check(
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="create"),
 			parameters={
 				"username":username,
@@ -127,11 +127,11 @@ class Users(_defaults_.Defaults):
 		# check password.
 		password = str(password)
 		if len(password) < 8:
-			return Response.error("The password must contain at least 8 characters.")
+			return dev0s.response.error("The password must contain at least 8 characters.")
 		elif password.lower() == password:
-			return Response.error("The password must regular and capital letters.")
+			return dev0s.response.error("The password must regular and capital letters.")
 		elif verify_password != None and password != str(verify_password):
-			return Response.error("Passwords do not match.")
+			return dev0s.response.error("Passwords do not match.")
 
 		# create django user.
 		response = self.django.users.create(
@@ -173,7 +173,7 @@ class Users(_defaults_.Defaults):
 		}
 
 		# handle success.
-		return Response.success(f"Successfully created user [{email}].", {
+		return dev0s.response.success(f"Successfully created user [{email}].", {
 			"user":user,
 			"email":user.email,
 			"data":data,
@@ -200,15 +200,15 @@ class Users(_defaults_.Defaults):
 
 		# check password.
 		if password != None:
-			if verify_password == None: return Response.error("Specify parameter: verify_password.")
+			if verify_password == None: return dev0s.response.error("Specify parameter: verify_password.")
 			password = str(password)
 			verify_password = str(verify_password)
 			if len(password) < 8:
-				return Response.error("The password must contain at least 8 characters.")
+				return dev0s.response.error("The password must contain at least 8 characters.")
 			elif password.lower() == password:
-				return Response.error("The password must regular and capital letters.")
+				return dev0s.response.error("The password must regular and capital letters.")
 			elif password != verify_password:
-				return Response.error("Passwords do not match.")
+				return dev0s.response.error("Passwords do not match.")
 		
 		# create django user.
 		response = self.django.users.update(
@@ -240,7 +240,7 @@ class Users(_defaults_.Defaults):
 			if not response.success: return response
 
 		# handle success.
-		return Response.success(f"Successfully updated user [{email}].")
+		return dev0s.response.success(f"Successfully updated user [{email}].")
 		
 		#
 	def delete(self, 
@@ -255,7 +255,7 @@ class Users(_defaults_.Defaults):
 
 		# check parameters.
 		if [username,email] == [None,None]:
-			return Response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
+			return dev0s.response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
 
 		# delete django user.
 		response = self.django.users.delete(username=username, email=email)
@@ -266,7 +266,7 @@ class Users(_defaults_.Defaults):
 		if not response.success: return response
 
 		# handle success.
-		return Response.success(f"Successfully deleted user [{email}].")
+		return dev0s.response.success(f"Successfully deleted user [{email}].")
 
 		#
 	def exists(self, 
@@ -301,7 +301,7 @@ class Users(_defaults_.Defaults):
 	):
 
 		# check parameters.
-		response = Response.parameters.check(
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="authenticate"),
 			parameters={
 				"username":username,
@@ -323,7 +323,7 @@ class Users(_defaults_.Defaults):
 				if not response.success: return response
 
 				# handler for sign in.
-				return Response.error(f"Authentication verification code required.")
+				return dev0s.response.error(f"Authentication verification code required.")
 
 			# verify code.
 			response = self.verify_code(username, code=_2fa_code, mode="authentication")
@@ -342,11 +342,11 @@ class Users(_defaults_.Defaults):
 		request=None,
 	):
 		if request.user in [None] or request.user.username in [None, ""]:
-			return Response.error("There is no user signed in.")
+			return dev0s.response.error("There is no user signed in.")
 		try:
 			_logout_(request)
-		except Exception as e:  return Response.error(f"Failed to sign out user [{request.user.username}], error: {e}.")
-		return Response.success("Successfully signed out.")
+		except Exception as e:  return dev0s.response.error(f"Failed to sign out user [{request.user.username}], error: {e}.")
+		return dev0s.response.success("Successfully signed out.")
 		#
 	def authenticated(self, 
 		# the request (#1).
@@ -355,21 +355,21 @@ class Users(_defaults_.Defaults):
 
 		# by request user filled (django).
 		if request.user.is_authenticated:
-			return Response.success(f"User {request.user.username} is authenticated.", {
+			return dev0s.response.success(f"User {request.user.username} is authenticated.", {
 				"api_key":None,
 				"email":request.user.email,
 				"username":request.user.username,
 			})
 
 		# by api key.
-		optional_parameters, _ = Response.parameters.get(request, {
+		optional_parameters, _ = dev0s.response.parameters.get(request, {
 			"api_key":None,
 		})
 		if optional_parameters["api_key"] != None:
 			return self.verify_api_key(api_key=optional_parameters["api_key"])
 
 		# error.
-		return Response.error("User is not authenticated, please specify your api key or login.")
+		return dev0s.response.error("User is not authenticated, please specify your api key or login.")
 
 		#
 	def root_permission(self, 
@@ -379,7 +379,7 @@ class Users(_defaults_.Defaults):
 
 		# by request user filled (django).
 		if request.user != None and request.user.is_authenticated and request.user.is_superuser:
-			return Response.success(f"Root permission granted ({request.user.username}).", {
+			return dev0s.response.success(f"Root permission granted ({request.user.username}).", {
 				"api_key":None,
 				"email":request.user.email,
 				"username":request.user.username,
@@ -389,7 +389,7 @@ class Users(_defaults_.Defaults):
 		# never root permission.
 
 		# error.
-		return Response.error("Root permission denied.")
+		return dev0s.response.error("Root permission denied.")
 
 		#
 	def load_data(self,
@@ -402,10 +402,10 @@ class Users(_defaults_.Defaults):
 	):	
 		username, email = self.__correct_username_email__(username, email)
 		if [username,email] == [None,None]:
-			return Response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
+			return dev0s.response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
 		response = self.db.load(path=self.__get_path__(email=email, username=username, create=create))
 		if response.error != None: return response
-		return Response.success(f"Successfully loaded the data of user [{email}].", {
+		return dev0s.response.success(f"Successfully loaded the data of user [{email}].", {
 			"data":response["data"],
 		})
 	def save_data(self,
@@ -420,10 +420,10 @@ class Users(_defaults_.Defaults):
 	):
 		username, email = self.__correct_username_email__(username, email)
 		if [username,email] == [None,None]:
-			return Response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
+			return dev0s.response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
 		response = self.db.save(path=self.__get_path__(email=email, username=username, create=True), data=data, overwrite=overwrite)
 		if response.error != None: return response
-		return Response.success(f"Successfully saved the data of user [{email}].")
+		return dev0s.response.success(f"Successfully saved the data of user [{email}].")
 	def send_email(self, 
 		# define email to retrieve user.
 		email=None, 
@@ -448,8 +448,8 @@ class Users(_defaults_.Defaults):
 		user = response["user"]
 		
 		# send email.
-		if Defaults.options.log_level >= 1:
-			Response.log(f"Sending email to user [{user.username}], email [{user.email}].")
+		if dev0s.defaults.options.log_level >= 1:
+			dev0s.response.log(f"Sending email to user [{user.username}], email [{user.email}].")
 		response = self.email.send(
 			subject=title,
 			recipients=[user.email], 
@@ -464,7 +464,7 @@ class Users(_defaults_.Defaults):
 			if response.error != None: return response
 
 		# success.
-		return Response.success(f"Successfully send an email to user [{user.email}].")
+		return dev0s.response.success(f"Successfully send an email to user [{user.email}].")
 
 		#
 	def send_code(self, 
@@ -525,8 +525,8 @@ class Users(_defaults_.Defaults):
 		print(html)
 
 		# send email.
-		if Defaults.options.log_level >= 1:
-			Response.log(f"Sending [{mode}] code to user [{user.username}], email [{user.email}].")
+		if dev0s.defaults.options.log_level >= 1:
+			dev0s.response.log(f"Sending [{mode}] code to user [{user.username}], email [{user.email}].")
 		response = self.email.send(
 			subject=f'{title} - Verification Code',
 			recipients=[user.email], 
@@ -541,7 +541,7 @@ class Users(_defaults_.Defaults):
 			if response.error != None: return response
 
 		# success.
-		return Response.success(f"Successfully send a verification code to user [{user.email}].")
+		return dev0s.response.success(f"Successfully send a verification code to user [{user.email}].")
 
 		#
 	def verify_code(self, 
@@ -576,22 +576,22 @@ class Users(_defaults_.Defaults):
 		except KeyError: fail = True
 		# handle.
 		if fail: 
-			return Response.error("Incorrect verification code.")
+			return dev0s.response.error("Incorrect verification code.")
 		elif not success: 
 			self.__verification_codes__[mode][user.email]["attempts"] -= 1
 			self.__verification_codes__.save()
-			return Response.error("Incorrect verification code.")
+			return dev0s.response.error("Incorrect verification code.")
 		else:
 			del self.__verification_codes__[mode][user.email]
 			self.__verification_codes__.save()
-			return Response.success("Successfull verification.")
+			return dev0s.response.success("Successfull verification.")
 
 		#
 	def verify_api_key(self, api_key=None, request=None):
 		
 		# by request.
 		if request != None:
-			parameters, response = Response.parameters.get(request, ["api_key"])
+			parameters, response = dev0s.response.parameters.get(request, ["api_key"])
 			if not response.success: return response
 			return self.verify_api_key(api_key=parameters["api_key"])
 		
@@ -606,14 +606,14 @@ class Users(_defaults_.Defaults):
 			# check api key.
 			for _api_key_, info in api_keys.items():
 				if _api_key_ == api_key: 
-					return Response.success(f"Successfully verified api key [{api_key}].", {
+					return dev0s.response.success(f"Successfully verified api key [{api_key}].", {
 						"email":info["email"],
 						"username":info["username"],
 						"api_key":api_key,
 					})
 
 			# error.
-			return Response.error(f"Unable to verify api key [{api_key}].")
+			return dev0s.response.error(f"Unable to verify api key [{api_key}].")
 
 			#
 	def verify_subscription(self,
@@ -685,7 +685,7 @@ class Users(_defaults_.Defaults):
 
 		# handlers.
 		if verified:
-			return Response.success(f"Successfully verified subscription {product} for user {id}.", {
+			return dev0s.response.success(f"Successfully verified subscription {product} for user {id}.", {
 				"email":email,
 				"api_key":api_key,
 				"product":product,
@@ -696,7 +696,7 @@ class Users(_defaults_.Defaults):
 			for i in required_plans: 
 				if _required_plans_ == "": _required_plans_ = i
 				else: _required_plans_ += ", "+i
-			return Response.error(f"Permission denied ({email}). This request requires at least one of the following plans for {product} [{_required_plans_}].")
+			return dev0s.response.error(f"Permission denied ({email}). This request requires at least one of the following plans for {product} [{_required_plans_}].")
 
 		#
 	def create_subscription(self,
@@ -724,8 +724,8 @@ class Users(_defaults_.Defaults):
 		username, email = self.__correct_username_email__(username, email)
 
 		# checkparameters.
-		if username == None and email == None and api_key == None: return Response.error("Define one of the following parameters: [email, api_key].")
-		response = Response.parameters.check(
+		if username == None and email == None and api_key == None: return dev0s.response.error("Define one of the following parameters: [email, api_key].")
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="create_subscription"),
 			parameters={
 				"product":product,
@@ -736,7 +736,7 @@ class Users(_defaults_.Defaults):
 		if card_cvc == "***" and "************" in card_number:
 			blinded = True
 		if not blinded:
-			response = Response.parameters.check(
+			response = dev0s.response.parameters.check(
 				traceback=self.__traceback__(function="create_subscription"),
 				parameters={
 					"card_name":card_name,
@@ -796,7 +796,7 @@ class Users(_defaults_.Defaults):
 
 		# check already subscribed.
 		if plan_id in plan_ids:
-			return Response.error(f"User {email} is already subscribed to plan {plan} from product {product}.")
+			return dev0s.response.error(f"User {email} is already subscribed to plan {plan} from product {product}.")
 
 		# create card when card is not blinded (aka retrieved from user).
 		if not blinded:
@@ -819,14 +819,14 @@ class Users(_defaults_.Defaults):
 		if not response.success: return response
 		
 		# handlers.
-		return Response.success(f"Successfully created subscription {product} {plan} for user {id}.")
+		return dev0s.response.success(f"Successfully created subscription {product} {plan} for user {id}.")
 
 		#
 	def get_api_key(self, email=None, username=None):
 
 		# check.
 		if [username,email] == [None,None]:
-			return Response.error("Define one of the following parameters: [email, username].")
+			return dev0s.response.error("Define one of the following parameters: [email, username].")
 		if username == None: id = email
 		elif email == None: id = username
 
@@ -842,11 +842,11 @@ class Users(_defaults_.Defaults):
 				api_key = _api_key_
 				break
 		if api_key != None:
-			return Response.success(f"Successfully retrieved the api key [{id}].", {
+			return dev0s.response.success(f"Successfully retrieved the api key [{id}].", {
 				"api_key":api_key,
 			})
 		else:
-			return Response.error(f"Unable to find api key [{id}].")
+			return dev0s.response.error(f"Unable to find api key [{id}].")
 
 		#
 	def set_permission(self, email=None, username=None, permission_id=None, permission=True):
@@ -864,7 +864,7 @@ class Users(_defaults_.Defaults):
 		if response.error != None: return response
 
 		# handlers.
-		return Response.success(f"Successfully set the {permission_id} permission of user [{email}] to [{permission}].")
+		return dev0s.response.success(f"Successfully set the {permission_id} permission of user [{email}] to [{permission}].")
 		#
 
 	# user passwords.
@@ -876,7 +876,7 @@ class Users(_defaults_.Defaults):
 		# the strong password boolean.
 		strong=False,
 	):
-		response =Response.parameters.check(
+		response =dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="check_password"),
 			parameters={
 				"password:str,String":password,
@@ -885,36 +885,36 @@ class Users(_defaults_.Defaults):
 			})
 		if not response.success: return response
 		if password != verify_password:
-			return Response.error("Passwords do not match.")
+			return dev0s.response.error("Passwords do not match.")
 		elif (not strong and len(password) < 6) or (strong and len(password) < 12):
-			return Response.error("The password must contain at least 12 characters.")
+			return dev0s.response.error("The password must contain at least 12 characters.")
 		elif password.lower() == password:
-			return Response.error("The password must contain capital letters.")
+			return dev0s.response.error("The password must contain capital letters.")
 		match = False
 		for i in [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]:
 			if  str(i) in password: match = True ; break
 		if match == False:
-			return Response.error("The password must contain digits.")
-		return Response.success("Succesfully checked the password.")
+			return dev0s.response.error("The password must contain digits.")
+		return dev0s.response.success("Succesfully checked the password.")
 	def load_password(self, email=None, username=None):
 		username, email = self.__correct_username_email__(username, email)
 		if [username,email] == [None,None]:
-			return Response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
+			return dev0s.response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
 		response = self.load_data(email=email, username=username)
 		if not response.success: return response
 		data = response.data
 		_response_ = self.encryption.decrypt(data["account"]["password"])
 		if not _response_.success: return _response_
 		password = _response_["decrypted"].decode()
-		return Response.success(f"Successfully retrieved the password of user {email}.",{
+		return dev0s.response.success(f"Successfully retrieved the password of user {email}.",{
 			"password":password,
 			"data":data,
 		})
 	def save_password(self, email=None, username=None, password=None):
 		username, email = self.__correct_username_email__(username, email)
 		if [username,email] == [None,None]:
-			return Response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
-		response = Response.parameters.check(
+			return dev0s.response.error(self.__traceback__(function="load_data")+" Define one of the following parameters [email, username].")
+		response = dev0s.response.parameters.check(
 			traceback=self.__traceback__(function="save_password"),
 			parameters={
 				"password":password,
@@ -930,7 +930,7 @@ class Users(_defaults_.Defaults):
 		data["account"]["password"] = _response_["encrypted"].decode()
 		response = self.save_data(email=email, username=username, data=data)
 		if not response.success: return response
-		return Response.success(f"Successfully saved the password of user {email}.")
+		return dev0s.response.success(f"Successfully saved the password of user {email}.")
 
 	# iterations.
 	def iterate(self,
@@ -952,9 +952,9 @@ class Users(_defaults_.Defaults):
 
 		# checks.
 		if database not in database_options:
-			raise Exceptions.InvalidUsage(f"{self.__traceback__(function='iterate',parameter='database')}: Selected an invalid database option [{database}], valid options: [{Array(database_options).string(joiner=', ')}].")
+			raise dev0s.exceptions.InvalidUsage(f"{self.__traceback__(function='iterate',parameter='database')}: Selected an invalid database option [{database}], valid options: [{Array(database_options).string(joiner=', ')}].")
 		if filter not in filter_options:
-			raise Exceptions.InvalidUsage(f"{self.__traceback__(function='iterate',parameter='filter')}: Selected an invalid filter option [{filter}], valid options: [{Array(filter_options).string(joiner=', ')}].")
+			raise dev0s.exceptions.InvalidUsage(f"{self.__traceback__(function='iterate',parameter='filter')}: Selected an invalid filter option [{filter}], valid options: [{Array(filter_options).string(joiner=', ')}].")
 
 		
 
@@ -972,7 +972,7 @@ class Users(_defaults_.Defaults):
 				elif filter == "data":
 					response = self.load_data(email=user.email, username=user.username)
 					if not response.success: 
-						Response.log(f"Unable to iterate user: [{user.username}]  (#346346) (error: {response.error}).")
+						dev0s.response.log(f"Unable to iterate user: [{user.username}]  (#346346) (error: {response.error}).")
 					else:
 						items.append(response["data"])
 
@@ -986,13 +986,13 @@ class Users(_defaults_.Defaults):
 				elif email != None: id = email
 				response = self.load_data(email=email, username=username)
 				if not response.success: 
-					Response.log(f"Unable to iterate user: [{id}] (#837028) (error: {response.error}).")
+					dev0s.response.log(f"Unable to iterate user: [{id}] (#837028) (error: {response.error}).")
 				else:
 					username, email = response["data"]["account"]["username"], response["data"]["account"]["email"]
 					if filter == "user":
 						response = self.django.users.get(email=email, username=username)
 						if not response.success: 
-							Response.log(f"Unable to iterate (django) user: [{username}].")
+							dev0s.response.log(f"Unable to iterate (django) user: [{username}].")
 						else:
 							items.append(response["user"])
 					elif filter == "email":
@@ -1091,7 +1091,7 @@ class Users(_defaults_.Defaults):
 			}
 			
 		# success.
-		return Response.success(f"Successfully synchronized {len(_usernames_)} user(s).", {
+		return dev0s.response.success(f"Successfully synchronized {len(_usernames_)} user(s).", {
 			"api_keys":api_keys,
 		})
 
@@ -1105,9 +1105,9 @@ class Users(_defaults_.Defaults):
 	def __initialize_email__(self):
 		# the email object.
 		if not self.email_enabled:
-			return Response.error("The email object is disabled.")
+			return dev0s.response.error("The email object is disabled.")
 		if self.email_address == None or self.email_password == None:
-			return Response.error("Define the firebase.users.email_address & firebase.users.email_password variables to send emails.")
+			return dev0s.response.error("Define the firebase.users.email_address & firebase.users.email_password variables to send emails.")
 		self.email = email.Email(
 			email=self.email_address,
 			password=self.email_password,
@@ -1116,7 +1116,7 @@ class Users(_defaults_.Defaults):
 			visible_email=self.visible_email,)
 		response = self.email.login()
 		if response["success"]:
-			return Response.success("Successfully initialized the mail object.")
+			return dev0s.response.success("Successfully initialized the mail object.")
 		else: 
 			self.email = None
 			return response
@@ -1151,7 +1151,7 @@ class Users(_defaults_.Defaults):
 			self.__timestamps__[mode] = Date()
 
 		# handler.
-		return Response.success("Successfully retrieved the stripe subscriptions cache.", {
+		return dev0s.response.success("Successfully retrieved the stripe subscriptions cache.", {
 			"subscriptions":subscriptions,
 		})
 
@@ -1187,7 +1187,7 @@ class Users(_defaults_.Defaults):
 			self.__timestamps__[mode] = Date()
 
 		# handler.
-		return Response.success("Successfully retrieved the api keys cache.", {
+		return dev0s.response.success("Successfully retrieved the api keys cache.", {
 			"api_keys":api_keys,
 		})
 
